#
# spec file for package boinc-client
#
# Copyright (c) 2020 SUSE LLC
# Copyright (c) 2016 by Aaron Puchert <aaronpuchert@alice-dsl.net>
# Copyright (c) 2011 by Sascha Manns <saigkill@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

%define sonum 7
%define boinc_dir %{_localstatedir}/lib/boinc

# do not build boinc-manager on SLES 11/12
%if 0%{?is_opensuse}
%bcond_without  manager
%else
%bcond_with     manager
%endif

Name:           boinc-client
%define rel_name        %{name}_release
%define minor_version   7.16
Version:        %{minor_version}.6
Release:        bp153.1.19
Summary:        Client for Berkeley Open Infrastructure for Network Computing
License:        GPL-3.0-or-later OR LGPL-3.0-or-later
Group:          Productivity/Clustering/Computing
URL:            https://boinc.berkeley.edu/

#Git-Clone:     https://github.com/BOINC/boinc
Source0:        https://github.com/BOINC/boinc/archive/client_release/%{minor_version}/%{version}.tar.gz
Source1:        boinc-icons.tar.bz2
Source2:        boinc-gui.desktop
Source3:        README.SUSE
Source4:        sysconfig.%{name}
Source5:        boinc-logrotate
Source6:        boinc-manager
Source10:       %{name}.init
Source20:       %{name}.service
Source100:      %{name}-rpmlintrc
Patch1:         boinc-guirpcauth.patch
Patch2:         boinc-docbook2x.patch
Patch4:         xlocale.patch
Patch5:         build-client-scripts.patch
Patch6:         libboinc-shared.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
#
BuildRequires:  Mesa-devel
BuildRequires:  docbook2x
BuildRequires:  docbook_4
BuildRequires:  fdupes
BuildRequires:  freeglut-devel
BuildRequires:  gcc-c++
BuildRequires:  gcc-fortran
BuildRequires:  gettext-runtime
BuildRequires:  libcurl-devel >= 7.17.1
BuildRequires:  libjpeg-devel
BuildRequires:  libnotify-devel
BuildRequires:  libtool
BuildRequires:  openssl-devel
BuildRequires:  pkg-config
BuildRequires:  pwdutils
BuildRequires:  sqlite3-devel
BuildRequires:  xorg-x11-libXmu-devel
Requires(pre):  pwdutils
Requires:       ca-certificates-mozilla
Recommends:     boinc-client-lang = %{version}
Recommends:     logrotate
#
%if 0%{?suse_version} >= 1310
BuildRequires:  libXi-devel
BuildRequires:  libxcb-devel
BuildRequires:  xcb-util-devel
%else
BuildRequires:  xorg-x11-libxcb-devel
%endif
#
%if 0%{?suse_version} >= 1210
BuildRequires:  pkgconfig(systemd)
%define has_systemd 1
%else
Requires(pre):  %fillup_prereq
Requires(pre):  %insserv_prereq
%endif
#
%if %{with manager}
BuildRequires:  update-desktop-files
BuildRequires:  wxWidgets-3_0-devel >= 3.0.2
%lang_package -n boinc-manager
%endif
#
%lang_package

%description
The Berkeley Open Infrastructure for Network Computing (BOINC) is a
software platform which supports distributed computing, primarily in
the form of "volunteer" computing and "desktop grid" computing. It is
well suited for problems which are often described as "trivially
parallel". BOINC is the underlying software used by projects such as
SETI@home, Einstein@Home, ClimatePrediciton.net, the World Community
Grid, and many other distributed computing projects.

This package installs the BOINC client software, which will allow
your computer to participate in one or more BOINC projects, using
your spare computer time to search for cures for diseases, model
protein folding, study global warming, discover sources of
gravitational waves, and many other types of scientific and
mathematical research.

%package -n boinc-manager
Summary:        GUI to control and monitor boinc-client
Group:          Productivity/Scientific/Astronomy
Recommends:     boinc-manager-lang = %{version}
Requires:       hicolor-icon-theme

%description -n boinc-manager
The BOINC Manager is a graphical monitor and control utility for the BOINC
core client. It gives a detailed overview of the state of the client it is
monitoring. The BOINC Manager has two modes of operation, the "Simple View" in
which it only displays the most important information and the "Advanced View"
in which all information and all control elements are available.

%package -n libboinc%{sonum}
Summary:        Berkeley Open Infrastructure For Network Computing library
Group:          System/Libraries

%description -n libboinc%{sonum}
The Berkeley Open Infrastructure for Network Computing (BOINC) is a
software platform which supports distributed computing.

%package -n libboinc-devel
Summary:        Development files for libboinc
Group:          Development/Libraries/C and C++
Requires:       libboinc%{sonum} = %{version}-%{release}
Conflicts:      %{name}-devel
Requires:       openssl-devel

%description -n libboinc-devel
This package contains development files for libboinc.

%prep
%global _lto_cflags %{_lto_cflags} -ffat-lto-objects
%setup -q -n %{name}_release-%{minor_version}-%{version} -D -a 1
%patch -P 1 -P 2 -P 4 -P 5 -P 6 -p1

%build
# Fix default path for boincscr
sed -i -e "s,/var/lib/boinc-client,%{boinc_dir},g" \
  clientscr/screensaver_x11.cpp

# Install user hints
install -m0644 %{SOURCE3} README.SUSE

# Fix lang directories (refer patch2)
mv locale/pt_PT locale/pt

# fix utf8
for i in 2005 2009 2010 2011; do
  iconv -f ISO88591 -t UTF8 < checkin_notes_$i > checkin_notes_$i.utf8
  touch -r checkin_notes_$i checkin_notes_$i.utf8
  mv checkin_notes_$i.utf8 checkin_notes_$i
done

## remove files with questionable licenses
# removing NVIDIA owned file that does not clearly allow redistribution or
# modification
rm -r coprocs/NVIDIA

# Remove unnecessary components and files for other platforms.
rm -r android drupal mac_build mac_installer win_build xcompile

autoreconf -fi
%configure \
  --enable-optimize \
  --enable-shared \
  --disable-static \
  --enable-dynamic-client-linkage \
  --enable-unicode \
  --disable-server \
  --disable-fcgi \
%if ! %{with manager}
  --disable-manager \
%endif
  --with-ssl

# Disable rpaths
sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool

# Export Path and make
make clean %{?_smp_mflags}
make libboinc_la_LIBADD="-L%{_libdir} -lssl -ldl" \
   CFLAGS="%{optflags} -g -W -pipe -fno-strict-aliasing -D_REENTRANT" \
   CXXFLAGS="%{optflags} -g -W -pipe -fno-strict-aliasing -D_REENTRANT" \
   DESTDIR=%{_prefix} %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
%if %{with manager}
for i in clientgui locale; do
%else
for i in locale; do
%endif
  pushd $i
  make DESTDIR=%{buildroot} install %{?_smp_mflags}
  popd
done

# Creates default folders
install -dm0755 %{buildroot}%{boinc_dir}
install -dm0755 %{buildroot}%{_mandir}/man1

# Remove old boinc & rename boinc_client to boinc-client
rm -f %{buildroot}%{_bindir}/boinc
mv -f %{buildroot}%{_bindir}/boinc_client %{buildroot}%{_bindir}/%{name}

%if %{with manager}
# Rename boincmgr and wrap it
mv %{buildroot}%{_bindir}/boincmgr %{buildroot}%{_bindir}/boinc-gui

# Install boinc-manager wrapper script
install -Dm0755 %{SOURCE6} %{buildroot}%{_bindir}/boinc-manager
%endif

# Use symlink instead of hardlink
pushd %{buildroot}%{_bindir}
ln -s -f %{name} boinc
%if %{with manager}
ln -s -f boinc-manager boincmgr
ln -s -f boinc-manager boincmanager
%endif
popd

%if %{with manager}
# replace @boinc_dir@, @bindir@
sed -i \
  -e "s,@boinc_dir@,%{boinc_dir},g" \
  -e "s,@bindir@,%{_bindir},g" \
  %{buildroot}%{_bindir}/boinc-manager
%endif

# Remove {buildroot}/etc/sysconfig/boinc-client, it is added by %%fillup_and_insserv
rm -f %{buildroot}%{_sysconfdir}/sysconfig/%{name}

# Install init and create symlink for rcboinc
install -dm0755 %{buildroot}%{_sbindir}
%if 0%{?has_systemd}
install -D -m0644 %{SOURCE20} %{buildroot}%{_unitdir}/%{name}.service
# And remove sysvinit script installed by boinc
rm -r %{buildroot}/%{_initddir}
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}
%else
install -Dm0755 %{SOURCE10} %{buildroot}%{_initddir}/%{name}
/bin/ln -sf %{_sysconfdir}/init.d/%{name} %{buildroot}%{_sbindir}/rc%{name}
%endif
# Install template for sysconfig
install -Dm0644 %{SOURCE4} %{buildroot}%{_fillupdir}/sysconfig.%{name}

# Install logrotate
install -Dm0644 %{SOURCE5} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}

# Install bash completion
install -Dpm0644 client/scripts/boinc.bash %{buildroot}%{_datadir}/bash-completion/completions/boinc

%if %{with manager}
# Install desktop-file and icons
install -Dm0644 boinc-gui-128.png %{buildroot}%{_datadir}/icons/hicolor/128x128/apps/boinc-gui.png
install -Dm0644 boinc-gui-64.png %{buildroot}%{_datadir}/icons/hicolor/64x64/apps/boinc-gui.png
install -Dm0644 boinc-gui-48.png %{buildroot}%{_datadir}/icons/hicolor/48x48/apps/boinc-gui.png
install -Dm0644 boinc-gui-32.png %{buildroot}%{_datadir}/icons/hicolor/32x32/apps/boinc-gui.png
install -Dm0644 boinc-gui-22.png %{buildroot}%{_datadir}/icons/hicolor/22x22/apps/boinc-gui.png
install -Dm0644 boinc-gui-16.png %{buildroot}%{_datadir}/icons/hicolor/16x16/apps/boinc-gui.png

# Install *.desktop File
%suse_update_desktop_file -i boinc-gui Utility
%endif

# Remove static libraries, libtool archives
rm %{buildroot}%{_libdir}/*.la

# Relinking Manpages
%if %{with manager}
ln -s -f boincmgr.1.gz %{buildroot}%{_mandir}/man1/boinc-manager.1.gz
%endif
ln -s -f boinccmd.1.gz %{buildroot}%{_mandir}/man1/boinccmd.1.gz
ln -s -f boinc.1.gz %{buildroot}%{_mandir}/man1/boinc.1.gz

# Install fake /var/lib/boinc
install -dm0755 %{buildroot}%{_var}/lib/boinc

# Prepare $LANG Packages
%find_lang BOINC-Client
%if %{with manager}
%find_lang BOINC-Manager
%else
find %{buildroot}/%{_datadir}/locale/ -name "BOINC-Manager.mo" -exec rm -f \{\} \;
%endif

%fdupes -s %{buildroot}

%pre
getent group boinc >/dev/null || %{_sbindir}/groupadd -r boinc
# add user
getent passwd boinc >/dev/null || \
%{_sbindir}/useradd -c "BOINC Client" -d "%{_localstatedir}/lib/boinc" \
  -g boinc -r -s /sbin/nologin boinc
# fix replacing old sysconfig file (r21)
if [ -f %{_sysconfdir}/sysconfig/%{name} ]; then
  if ! grep -q "BOINC_BOINC_USR" %{_sysconfdir}/sysconfig/boinc-client; then
    mv -f %{_sysconfdir}/sysconfig/%{name} %{_sysconfdir}/sysconfig/%{name}.save
  fi
fi
%if 0%{?has_systemd}
%service_add_pre %{name}.service
%endif

%preun
%if 0%{?has_systemd}
%service_del_preun %{name}.service
%else
%stop_on_removal %{name}
%endif

%post
%if 0%{?has_systemd}
%{fillup_only}
%service_add_post %{name}.service
%else
%fillup_and_insserv %{name}
%endif
%{_sbindir}/usermod -c "BOINC Client" -s /sbin/nologin boinc 2>/dev/null || :

%postun
%if 0%{?has_systemd}
%service_del_postun %{name}.service
%else
%restart_on_update %{name}
%insserv_cleanup
%endif

%post -n boinc-manager
%{_bindir}/touch --no-create %{_datadir}/icons/hicolor || :
if [ -x %{_bindir}/gtk-update-icon-cache ]; then
  %{_bindir}/gtk-update-icon-cache --quiet %{_datadir}/icons/hicolor || :
fi

%postun -n boinc-manager
%{_bindir}/touch --no-create %{_datadir}/icons/hicolor || :
if [ -x %{_bindir}/gtk-update-icon-cache ]; then
  %{_bindir}/gtk-update-icon-cache --quiet %{_datadir}/icons/hicolor || :
fi

%post -n libboinc%{sonum} -p /sbin/ldconfig

%postun -n libboinc%{sonum} -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%license COPYING* COPYRIGHT
%doc README.SUSE
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%{_datadir}/bash-completion/completions/*
%{_bindir}/boinc
%{_bindir}/%{name}
%{_bindir}/boinccmd
%{_bindir}/switcher
%{_mandir}/man1/boinccmd.1.gz
%{_mandir}/man1/boinc.1.gz
%if 0%{?has_systemd}
%{_unitdir}/%{name}.service
%else
%{_initddir}/%{name}
%endif
%{_sbindir}/rc%{name}
%{_fillupdir}/sysconfig.%{name}
%defattr(-,boinc,boinc,-)
%{boinc_dir}/

%files -n %{name}-lang -f BOINC-Client.lang
%defattr(-,root,root)
%if 0%{?sles_version} == 11
%dir %{_datadir}/locale/fa_IR
%dir %{_datadir}/locale/fa_IR/LC_MESSAGES
%endif

%if %{with manager}
%files -n boinc-manager
%defattr(-,root,root,-)
%{_bindir}/boinc-gui
%{_bindir}/boinc-manager
%{_bindir}/boincmgr
%{_bindir}/boincmanager
%{_bindir}/boincscr
%{_datadir}/applications/boinc-gui.desktop
%{_datadir}/icons/hicolor/*/apps/*
%{_mandir}/man1/boincmgr.1.gz
%{_mandir}/man1/boinc-manager.1.gz

%files -n boinc-manager-lang -f BOINC-Manager.lang
%defattr(-,root,root)
%endif

%files -n libboinc%{sonum}
%defattr(-,root,root,-)
%{_libdir}/*.so.*

%files -n libboinc-devel
%defattr(-,root,root,-)
%{_libdir}/*.a
%{_libdir}/*.so
%{_includedir}/boinc

%changelog
* Wed Apr 22 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 7.16.6
  * client: add <ignore_tty> config file option (Unix)
  * client: if an output file is missing or bad length,
    mark workunit as error.
  * client: on startup, check for active task finish files.
  * client: fix bug in missing-file logic that cause task
    abort at startup.
  * client: fix bug that caused jobs to run after client exit.
  * client: don't unsuspend before sending quit message.
  * client: send task descriptions if requested by AM.
* Sun Dec  1 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 7.16.3
  * If output file is missing on startup, flag task as error.
  * Let project specify directories in logical file names.
  * Fix security vulnerability involving logical file names.
  * Make "reread config files" work for ncpus.
  * Support fetch of files over GUI RPC; allow projects to supply
    their own web-based GUI.
  * Support GUI RPCs as HTTP Post requests.
  * Enable "Other options" in simple view if no client connected.
  * Clear "vm_extensions_disabled" flag on startup.
  * Fix work fetch bug when max_concurrent used.
  * Unsuspend jobs before telling them to quit.
  * Sanity check job runtime limits.
  * Fix overflow in OpenCL GPU FLOPS calculation.
- Do not ignore errors from groupadd/useradd
* Tue Sep 10 2019 Christophe Giboudeaux <christophe@krop.fr>
- Build boinc-client using -ffat-lto-objects
* Sat Dec 15 2018 aaronpuchert@alice-dsl.net
- Update to version 7.14.2.
  * Fix GPU detection when run with --detach_console or using $PATH
  * Update NVIDIA GPU detection for recent models
  * Change simple prefs dialog behavior to match advanced
  * If using a dynamic account manager, show AM user name in
    Manager rather than randomly-generated project account names
  * Move new-version URLs from cc_config.xml to nvc_config.xml
    (so that WCG can customize)
* Mon Aug  6 2018 jengelh@inai.de
- Remove unnecessary ldconfig from devel subpackage
* Tue Jul 24 2018 aaronpuchert@alice-dsl.net
- Update to version 7.12.1.
- Remove doc package, since the files have been removed from the
  source. Actually it wasn't even the documentation, but the
  server code.
- Disable idle detection via the XSS API and remove dependency to
  libXScrnSaver-devel. This feature requires access to a running
  X server, which the BOINC client does not have in OpenSUSE.
- Rename the devel package and provide the correct dependency.
  The devel package provides the headers for libboinc, and has
  nothing to do with the BOINC client.
- Add conflict to original devel package.
- Remove unnecessary dependency to libxslt.
- Update systemd service file with changes from upstream: start
  after network-online.target, and use "ProtectHome=true".
- Move bash completion file to /usr/share tree to fix rpmlint.
- Declare license files as %%license.
- Don't install `notes` and `todo` - these are internal notes of
  the developers and not helpful to users.
- Drop 0001-MGR-support-wxWidgets-without-webview.patch, which has
  landed upstream (commit 27bb3c9e).
- libboinc-shared.patch: Build shared libraries for client and
  static libraries for science apps. Science apps are distributed
  as binaries over the BOINC network, so dynamic linking doesn't
  make sense. But we can use dynamic linking for the client.
- build-client-scripts.patch: Add some targets to fix build.
- Fix default path for boincscr.
* Wed Jul 11 2018 chris@computersalat.de
- Update to 7.8.6
  * can't find any useful ChangeLog :(
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Thu Oct 26 2017 chris@computersalat.de
- Update to version 7.8.3. (aaronpuchert)
- Removed the deprecated "Encoding" line from the .desktop file.
- Updated the cleanup code:
  * Permissions seem to be correct now.
  * Line endings seem to be correct.
  * Applied the UTF-8 conversion to the 2011 notes as well.
- Removed the entire coprocs/NVIDIA directory, since all files in
  there have a doubtful license.
- Removed components that are not required for a Linux build.
* Sun Sep 10 2017 chris@computersalat.de
- update to 7.8.2
  * no changelog available
- add {minor_version}
- rm wrong sim_web link
- fix files for SLES 11
- remove obsolete patch
  * 0001-Fix-1530-null-pointer-dereference.patch
* Fri Sep  8 2017 jengelh@inai.de
- Add 0001-MGR-support-wxWidgets-without-webview.patch
* Sat Sep  2 2017 jengelh@inai.de
- Remove unnecessary %%if..%%endif markers that do not affect the
  rpmbuild output files.
- Move patch metadata into patch so it stays with the patch.
  Add more authorship info.
- Add xlocale.patch to fix build error with glibc-2.26.
- Refresh boinc-guirpcauth.patch, boinc-docbook2x.patch,
  0001-Fix-1530-null-pointer-dereference.patch to quilt's default
  p1 level.
* Mon Mar 27 2017 chris@computersalat.de
- fix deps
  * add missing ca-certificates-mozilla
    needed in minimal install, e.g. JeOS images,
    without - boinc-client will fail to load config from
    e.g. www.worldcommunitygrid.org/get_project_config.php
* Sat Feb 25 2017 chris@computersalat.de
- fix for boo#1026965
  * no remote connect, no sysconfig file (--allow_remote_gui_rpc)
  * install and fillup sysconfig file
  * rework service file
- fix wrong bashism fix by ledest
  * grep should NOT match
- do not build boinc-manager on SLES 11/12
  * bcond_with manager
- revert conditionals remove for SLES 11
  * add SysVinit file
- mv boincscr to manager pkg, built with manager
* Mon Jan  2 2017 jengelh@inai.de
- Add argument passing from boinc-manager to boinc-gui [boo#1017705]
* Tue Dec 27 2016 jengelh@inai.de
- Update to new upstream release 7.6.33
  * Fix a crash near readdir (add
  0001-Fix-1530-null-pointer-dereference.patch)
* Sun Apr 24 2016 jengelh@inai.de
- Update to new upstream release 7.6.32
- Remove boinc-client-AM_CONDITIONAL.patch, boinc-configure.patch
  (no longer needed)
* Fri Apr 22 2016 aaronpuchert@alice-dsl.net
- Replaced quick fix for compiler errors by a proper solution,
  which is already upstreamed.
- Removed dependency to mysql, because that is only needed for the
  BOINC server, which we don't build anyway.
- Removed dependency to libboinc, because it's meant to be
  statically linked to science apps and not necessary for end user.
* Sun Mar 27 2016 aaronpuchert@alice-dsl.net
- Update to version 7.6.22. The main advantage: GPUs running on
  the open source stack (Mesa) are now recognized and can be used
  for BOINC. Additional packages are needed though:
  * libOpenCL1,
  * libMesaOpenCL,
  * libclc.
  Further, the GPU device in /dev/dri needs to have r+w rights for
  the BOINC user, since it doesn't have access to the X session.
- Fetch from GitHub instead of SVN, removed the fetch script
- Rebased all patches, removed obsolete boinc-LC_MESSAGES.patch
- Fixed compiler errors because openSUSEs wxWidgets is configured
  with wxUSE_STL=1, which is incompatible with BOINC. There is an
  open issue on GitHub: https://github.com/BOINC/boinc/issues/1515.
- Building the manager and locales separately is no longer
  necessary.
- The icons seem to have disappeared.
- The BOINC manager should be called with the data directory
  instead of the binary directory. Otherwise it can't connect.
* Wed Jun 24 2015 jengelh@inai.de
- boinc-client.service: replace ControlGroup= by Slice=, since
  ControlGroup is gone since systemd-205 already. We now use the
  "background.slice". Configuration of the background.slice is
  left to the administrator since it may be shared by other
  packages, and is subject to preferences. If you need some default
  to begin with for the first time,  use
  `systemctl set-property background.slice CPUShares=2`.
* Wed Mar 18 2015 jengelh@inai.de
- Reduce logrotate from Requires to Recommends.
- Remove Requires: cron. This seems only for the server parts
  (not in this package).
- Remove systemd requires to allow for a minimal container setup.
* Sun Nov  9 2014 Led <ledest@gmail.com>
- fix bashism in pre script
* Tue Jun 17 2014 tchvatal@suse.com
- Remove needless rpmlintrc lines to ease error spotting when there
  really are some.
* Tue Jun 17 2014 tchvatal@suse.com
- Cleanup with spec-cleaner for better readability
- Move lang packages from Requires to Recommends
* Tue Jun 17 2014 tchvatal@suse.com
- Remove unused patch:
  * boinc-completion.patch
- Remove comments with unused patches
- Remove conditionals with inits as we don't build for such release
  anyway
- Provide rcboinc symlink for easier usage.
* Wed Mar 26 2014 chris@computersalat.de
- some RPMLINT fixes
  * fix License: remove ','
  * non-standard-gid /var/lib/boinc boinc
  * SR #227671 to rpmlint
- fix deps for libxcb
* Tue Mar 18 2014 chris@computersalat.de
- fix README.SUSE
* Sun Mar 16 2014 chris@computersalat.de
  [#] fix for bnc#779335
  * disabled boinc-completion.patch
- update to 7.2.42
  * Fix problem that was causing scheduler RPCs to fail on Yoyo@home
    (HTTP status code 400)
  * for mor info have a look at
    http://boinc.berkeley.edu/wiki/Release_Notes
- removed obsolete patches:
  * boinc-client-dynamic_buffers.patch
  * boinc-init.patch
  * boinc-client-7.0.36-AM_CONDITIONAL.patch
  * boinc-client-7.0.36-dynamic_buffers.patch
- rebased patches:
  * boinc-LC_MESSAGES.patch
  * boinc-client-AM_CONDITIONAL.patch
  * boinc-configure.patch
  * boinc-docbook2x.patch
  * boinc-guirpcauth.patch
* Sat Oct 26 2013 p.drouand@gmail.com
- Update to version 7.0.36
  + No changelog available
- Add systemd support
- Adapt patchs to upstream changes
  * boinc-client-dynamic_buffers.patch
  * boinc-client-AM_CONDITIONAL.patch
- Remove boinc-client-glib_h.patch; fixed on upstream
- Do not copy INSTALL in documentation
* Wed May  1 2013 chris@computersalat.de
- update to 7.0.28
  * sorry but there is no ChangeLog :(
- rebase patches
  * dynamic_buffers, guirpcauth, AM_CONDITIONAL
- add configure patch
- remove obsolete glib_h patch
* Wed Apr  3 2013 coolo@suse.com
- do not own bash directories
* Tue Jul 10 2012 chris@computersalat.de
- rename patch
  * fix-automake-conditional to boinc-client-AM_CONDITIONAL patch
- fix build for SLE_11
  * AM_CONDITIONAL patch >= 12.2
* Tue Jul 10 2012 coolo@suse.com
- fix compilation for factory and 12.2
* Sun Jul  1 2012 chris@computersalat.de
- add BOINC_DIR to sysconfig
  * make BOINC_DIR configurable (a proposal of Carsten Neumann)
* Sat Feb 11 2012 chris@computersalat.de
- add glib_h patch
* Fri Feb 10 2012 chris@computersalat.de
- update tp 6.12.43
  * sorry but there is no ChangeLog :(
- rework patches
- remove obsolete patches
  * boinc-server.patch
  * boinc-client-str_util.patch
- add boinc-client-lang subpkg
- fix DSOLinkChange for suse >= 1210
  * see https://fedoraproject.org/wiki/UnderstandingDSOLinkChange
    for more info, special thanks to Stefan Dirsch :)
* Fri Feb 10 2012 chris@computersalat.de
- fix sed for boinc-manager
* Wed Feb  8 2012 chris@computersalat.de
- fix for bnc#745887 ( Confirm licensing of boinc-client 6.10.60 )
- fix for bnc#744612 ( File /usr/bin/boinc_gui incorrectly named )
- fix for bnc#744389 ( boinc-client will not run )
- fix for bnc#732118 ( BOINC installs but will not run )
* Mon Feb  6 2012 chris@computersalat.de
- fix License (http://www.spdx.org/licenses/)
  * LGPL-3.0
* Sun Feb  5 2012 chris@computersalat.de
- remove client dep of manager
  * manager does not really need a local boinc-client ;)
- fix desktop file
* Sat Feb  4 2012 chris@computersalat.de
- fix deps for boinc-client
  * Requires libboinc6
* Thu Feb  2 2012 chris@computersalat.de
- rework patches
- rework sysconfig file
- rework logrotate file
- add SuSElike init script
- fix user add
  * boinc needs a shell
- fix wrapper
  * replace boincmanager with boinc-manager and add symlink for
    backward compatibility
  * fix boinc_gui -> boinc-gui
- fix License
  * LGPLv3
- fix for bnc#689499
  * a blocked boinc client, the manager works
* Fri Sep 30 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Tue Aug 30 2011 Sascha.Manns@open-slx.de
- fixed Bug bnc#714623 (/var/lock/subsys unsupported)
* Mon May 16 2011 pth@suse.de
- Avoid buffer overflow in filesys.cpp(dir_size).
* Sun May  1 2011 chris@computersalat.de
- update to 6.10.60
  * Fix: Project list issue in the attach wizard that lead to a crash
- fix deps
  o wxGTK-devel
- enable parallel build
* Fri Apr 29 2011 saigkill@opensuse.org
- filed shared-lib-calls-exit in boinc as
  http://boinc.berkeley.edu/trac/ticket/1098
- filed binary-or-shlib-calls-gethostbyname as
  http://boinc.berkeley.edu/trac/ticket/1099
* Thu Apr 28 2011 saigkill@opensuse.org
- Rewritten the Spec based on Malcolm Lewis Improvements (THX)
* Wed Apr 27 2011 saigkill@opensuse.org
- Removed boinc-bnc_465676.patch (Fixed Upstream)
- Removed boinc-bnc_465676.patch (Fixed Upstream)
- Removed boinc-client-NotebookWxPanel.patch (Fixed Upstream)
- Removed boinc-client-wxWindowListNode.patch (Fixed Upstream)
* Tue Dec 28 2010 sbrabec@suse.cz
- Compile with wxWidgets (STL variant).
* Tue Oct  5 2010 malcolmlewis@opensuse.org
- Fix boinc-manager-lang requires
* Tue Oct  5 2010 malcolmlewis@opensuse.org
- Major spec file makeover
- Updated version
- Cleaned up patches
- Fixed most deprecated conversion from string constant to 'char*'
* Mon Mar 15 2010 coolo@novell.com
- disable use of %%jobs
* Sun May 31 2009 saigkill@opensuse.org
- fixed str_util.h while using newer gcc (THX to Jan)
* Fri May 22 2009 saigkill@opensuse.org
- fixed Errors while using newer wx Version
* Fri Mar 27 2009 saigkill@opensuse.org
- removed boinctray depency
* Sat Mar 14 2009 saigkill@opensuse.org
- added rpmlintrc
* Wed Feb 25 2009 pth@suse.de
- Use wxWindowList::compatibility_iterator instead of wxWindowListNode*
  as the latter is not defined when wxWindows is compiled to use
  the STL.
- Include standard compiler flags.
- Reformat description
- Correct spelling boinc-client-README.SuSE
* Thu Feb 12 2009 saigkill@opensuse.org
- added wxstring_conversion.patch (fix Bug #774 Berkeley Bug)
* Wed Feb 11 2009 saigkill@opensuse.org
- first stable Version
- fixed boincmgr to copy gui_rpc_auth.cfg to every /home
* Wed Feb 11 2009 saigkill@opensuse.org
- Export %%%%changelog to boinc-client.changes
* Tue Feb 10 2009 saigkill@opensuse.org
- changed $BOINCEXE from boinc_client to boinc
* Wed Feb  4 2009 saigkill@opensuse.org
- Fixed OpenSUSE Bugzilla Bug #468414
* Tue Feb  3 2009 saigkill@opensuse.org
- updated to Version 6.4
- deleted bnc_465676 (was fixed in sourcecode by boinc-team)
* Mon Feb  2 2009 dl9pf@gmx.de
- tweaked -doc package
* Mon Feb  2 2009 saigkill@opensuse.org
- added README.SuSE to %%%%doc
- added own Patches:
  + boinc-docbook2x (fix using docbook2x)
  + boinc-LC_MESSAGES (fix handling .mo LC Messages)
  + boinc-rcscript (fix using init.d instead of rc.d)
  (fix BOINC User root)
  + boinc-sysconfig (fix installing conf in /etc/boinc-client.conf)
  (fix init File as boinc)
  + ca_cert_deactivate (fix deactivate using of ca_cert)
  + fs_start_included (fix add $fs_network to init.d Script)
* Sun Feb  1 2009 saigkill@opensuse.org
- added fillup Macro to use sysconfig
- use sysconfig.boinc as source from fillup macro
* Sat Jan 31 2009 saigkill@opensuse.org
- deleted bnc_431510 not relevant (for Mac).
- deleted bnc_439037 not relevant
- deleted bnc_442904 for Win. In my Package no Win/Mac Source
- added bnc_465676.patch fix CVE-ID: CVE-2009-0126
- branched for Factory:Contrib
* Fri Jan 23 2009 saigkill@opensuse.org
- deleted mac/mac_build/win Folders from the Sourcecode
* Wed Jan 14 2009 mauro@suse.de
- Added bnc_465676.patch to fix bnc#465676.
  + Fixes CVE-2008-5077
  + check return values of RSA_*() functions.
  + fix a memory leak, missing RSA_free().
* Tue Dec 23 2008 mauro@suse.de
- Added bnc_442904.patch to fix bnc#442904.
  + Use the proper delete.
* Mon Nov  3 2008 mauro@suse.de
- Add bnc_439037.patch to fix bnc#439037. We now use strcmp
  instead of the original ==.
* Fri Oct  3 2008 mauro@suse.de
- Add bnc-431510.patch to fix bnc#431510.
* Mon Sep  8 2008 mauro@suse.de
- initial package for SuSE. boinc 6.2.18 (based on the enzokiel's
  (opensuse version).
